CompilableNode

Trait CompilableNode 

pub trait CompilableNode<F: Field>: CircuitNode {
    // Required method
    fn generate_circuit_description(
        &self,
        circuit_map: &mut CircuitMap,
    ) -> Result<Vec<LayerDescriptionEnum<F>>>;
}
A Node that contains the information neccessary to Compile itself

Implement this for any node that does not need additional Layingout before compilation

TODO: Merge this with circuitnode

Required Methods

fn generate_circuit_description( &self, circuit_map: &mut CircuitMap, ) -> Result<Vec<LayerDescriptionEnum<F>>>

Generate the circuit description of a node, which represents the shape of a certain layer.

Implementors